module de2lab5b(
//	Clock Input
  CLOCK_50,	//	50 MHz
  CLOCK_27,     //      27 MHz
//	Push Button
  KEY,      //	Pushbutton[3:0]
//	DPDT Switch
  SW,		//	Toggle Switch[17:0]
//	7-SEG Display
	HEX0,HEX1,HEX2,HEX3,HEX4,HEX5,HEX6,HEX7,  // Seven Segment Digits
//	LED
	LEDG,  //	LED Green[8:0]
	LEDR,  //	LED Red[17:0]
//	GPIO
	GPIO_0,GPIO_1,	//	GPIO Connections
//	TV Decoder
//TD_DATA,    		//	TV Decoder Data bus 8 bits
//TD_HS,		//	TV Decoder H_SYNC
//TD_VS,		//	TV Decoder V_SYNC
	TD_RESET,	//	TV Decoder Reset
// I2C
	I2C_SDAT,	//	I2C Data
	I2C_SCLK,	//	I2C Clock
// Audio CODEC
	AUD_ADCLRCK,	//	Audio CODEC ADC LR Clock
	AUD_ADCDAT,	//	Audio CODEC ADC Data
	AUD_DACLRCK,	//	Audio CODEC DAC LR Clock
	AUD_DACDAT,	//	Audio CODEC DAC Data
	AUD_BCLK,	//	Audio CODEC Bit-Stream Clock
	AUD_XCK		//	Audio CODEC Chip Clock
);

//	Clock Input
input	CLOCK_50;	//	50 MHz
input	CLOCK_27;	//	27 MHz
//	Push Button
input	[3:0]	KEY;		//	Pushbutton[3:0]
//	DPDT Switch	
input	[17:0]	SW;			//	Toggle Switch[17:0]
//	7-SEG Displays
output	[6:0]	HEX0, HEX1, HEX2, HEX3, HEX4, HEX5, HEX6, HEX7;					//	Seven Segment Digit 0
//	LED
output	[8:0]	LEDG;	//	LED Green[8:0]
output	[17:0]	LEDR;	//	LED Red[17:0]
//	GPIO Connections
inout	[35:0]	GPIO_0, GPIO_1;

// I2C
inout   I2C_SDAT;	//	I2C Data
output	I2C_SCLK;	//	I2C Clock

//	TV Decoder
//input	[7:0]	TD_DATA;    //	TV Decoder Data bus 8 bits
//input			TD_HS;		//	TV Decoder H_SYNC
//input			TD_VS;		//	TV Decoder V_SYNC
output			TD_RESET;	//	TV Decoder Reset

//	Audio CODEC		////////////////////////////
output/*inout*/	AUD_ADCLRCK;	//	Audio CODEC ADC LR Clock
input		AUD_ADCDAT;	//	Audio CODEC ADC Data
inout		AUD_DACLRCK;	//	Audio CODEC DAC LR Clock
output		AUD_DACDAT;	//	Audio CODEC DAC Data
inout		AUD_BCLK;	//	Audio CODEC Bit-Stream Clock
output		AUD_XCK;	//	Audio CODEC Chip Clock

//	All inout port turn to tri-state
assign	GPIO_0		=	36'hzzzzzzzzz;
assign	GPIO_1		=	36'hzzzzzzzzz;

wire [6:0] myclock;
wire RST;
assign RST = KEY[0];

// reset delay gives some time for peripherals to initialize
wire DLY_RST;
Reset_Delay r0(	.iCLK(CLOCK_50),.oRESET(DLY_RST) );

// Send switches to red leds 
assign LEDR = SW;

// Turn off green leds
assign LEDG = 8'h00;


// blank unused 7-segment digits
assign HEX0 = 7'b111_1111;
assign HEX1 = 7'b111_1111;
assign HEX2 = 7'b111_1111;
assign HEX3 = 7'b111_1111;
assign HEX4 = 7'b111_1111;
assign HEX5 = 7'b111_1111;
assign HEX6 = 7'b111_1111;
assign HEX7 = 7'b111_1111;


assign	TD_RESET	=	1'b1;	//	Enable 27 MHz

wire VGA_CTRL_CLK, AUD_CTRL_CLK, VGA_CLK;

VGA_Audio_PLL 	p1 (	
	.areset(~DLY_RST),
	.inclk0(CLOCK_27),
	.c0(VGA_CTRL_CLK),
	.c1(AUD_CTRL_CLK),
	.c2(VGA_CLK)
);

I2C_AV_Config 	u3(	
//	Host Side
  .iCLK(CLOCK_50),
  .iRST_N(KEY[0]),
//	I2C Side
  .I2C_SCLK(I2C_SCLK),
  .I2C_SDAT(I2C_SDAT)	
);

assign	AUD_ADCLRCK	=	AUD_DACLRCK;
assign	AUD_XCK		=	AUD_CTRL_CLK;

//set up DDS frequency
//Use switches to set freq
wire [31:0] dds_incr;
assign dds_incr = SW * 89478 ; //89478 = 2^32/48000 so SW is in Hz

AUDIO_DAC u4(	
//	Audio Side
   .oAUD_BCK(AUD_BCLK),
   .oAUD_DATA(AUD_DACDAT),
   .oAUD_LRCK(AUD_DACLRCK),
//	Control Signals
   .iDDS_incr(dds_incr),
  .iCLK_18_4(AUD_CTRL_CLK),
   .iRST_N(DLY_RST)	
);

endmodule